@@ -6,7 +6,7 @@ from django.core.urlresolvers import reverse
 from django.test import TestCase
 from django.utils.translation import ugettext as _
 
-from backbone.tests.models import Product, Brand, Category, ExtendedProduct
+from backbone.tests.models import Product, Brand, Category, ExtendedProduct, DisplayFieldsProduct
 from backbone.tests.backbone_api import BrandBackboneView
 
 
@@ -39,6 +39,16 @@ class TestHelper(TestCase):
         defaults.update(kwargs)
         return ExtendedProduct.objects.create(**defaults)
 
+    def create_displayfields_product(self, **kwargs):
+        defaults = {
+            'name': 'Beta Product',
+            'price': '13.32'
+        }
+        if 'brand' not in kwargs:
+            defaults['brand'] = self.create_brand()
+        defaults.update(kwargs)
+        return DisplayFieldsProduct.objects.create(**defaults)
+
     def create_brand(self, **kwargs):
         defaults = {
             'name': 'Test Brand',
@@ -167,6 +177,15 @@ class CollectionTests(TestHelper):
         response = self.client.get(url, {'page': 999})
         self.assertEqual(response.status_code, 200)
 
+    def test_collection_view_for_view_with_custom_url_slug(self):
+        brand = self.create_brand()
+        url = reverse('backbone:tests_brand_alternate')
+        response = self.client.get(url)
+        data = self.parseJsonResponse(response)
+        self.assertEqual(len(data), 1)
+        self.assertEqual(data[0]['id'], brand.id)
+        self.assertEqual(data[0]['custom'], 'foo')
+
 
 class DetailTests(TestHelper):
 
@@ -193,6 +212,59 @@ class DetailTests(TestHelper):
         # Callable on model
         self.assertEqual(data['get_first_category_id'], category.id)
 
+    def test_detail_view_uses_display_detail_fields_when_defined(self):
+        display_fields_product = self.create_displayfields_product(price=111)
+        category = self.create_category()
+        display_fields_product.categories.add(category)
+
+        url = reverse('backbone:tests_displayfieldsproduct_detail', args=[display_fields_product.id])
+        response = self.client.get(url)
+        data = self.parseJsonResponse(response)
+
+        self.assertEqual(data['id'], display_fields_product.id)
+        self.assertEqual(data['name'], display_fields_product.name)
+        self.assertEqual(data['brand'], display_fields_product.brand.id)
+        self.assertEqual(data['categories'], [category.id])
+        self.assertTrue('price' not in data)
+        self.assertTrue('order' not in data)
+        # Attribute on model
+        self.assertTrue('is_priced_under_10' not in data)
+        # Callable
+        self.assertTrue('sku' not in data)
+        # Callable on admin class
+        self.assertTrue('custom2' not in data)
+        # Callable on model
+        self.assertTrue('get_first_category_id' not in data)
+        self.assertEqual(len(data.keys()), 4)
+
+    def test_collection_view_uses_display_collection_fields_when_defined(self):
+        display_fields_product = self.create_displayfields_product(price=111)
+        category = self.create_category()
+        display_fields_product.categories.add(category)
+
+        url = reverse('backbone:tests_displayfieldsproduct')
+        response = self.client.get(url)
+        data = self.parseJsonResponse(response)
+
+        self.assertEqual(len(data), 1)
+
+        data = data[0]
+        self.assertEqual(data['id'], display_fields_product.id)
+        self.assertEqual(data['name'], display_fields_product.name)
+        self.assertEqual(data['brand'], display_fields_product.brand.id)
+        self.assertEqual(data['categories'], [category.id])
+        self.assertTrue('price' not in data)
+        self.assertTrue('order' not in data)
+        # Attribute on model
+        self.assertTrue('is_priced_under_10' not in data)
+        # Callable
+        self.assertTrue('sku' not in data)
+        # Callable on admin class
+        self.assertTrue('custom2' not in data)
+        # Callable on model
+        self.assertTrue('get_first_category_id' not in data)
+        self.assertEqual(len(data.keys()), 4)
+
     def test_detail_view_doesnt_return_unspecified_fields(self):
         product = self.create_product()
         url = reverse('backbone:tests_product_detail', args=[product.id])
@@ -218,6 +290,14 @@ class DetailTests(TestHelper):
         response = self.client.post(url)
         self.assertEqual(response.status_code, 403)
 
+    def test_detail_view_for_view_with_custom_url_slug(self):
+        brand = self.create_brand()
+        url = reverse('backbone:tests_brand_alternate_detail', args=[brand.id])
+        response = self.client.get(url)
+        data = self.parseJsonResponse(response)
+        self.assertEqual(data['id'], brand.id)
+        self.assertEqual(data['custom'], 'foo')
+
 
 class AddTests(TestHelper):
 
@@ -348,11 +428,27 @@ class AddTests(TestHelper):
         })
         url = reverse('backbone:tests_brand')
         response = self.client.post(url, data, content_type='application/json')
-        self.assertEqual(Product.objects.count(), 0)
+        self.assertEqual(Brand.objects.count(), 0)
         data = self.parseJsonResponse(response, status_code=400)
         self.assertEqual(len(data), 1)
         self.assertEqual(data['name'], [_('Brand name must start with a capital letter.')])
 
+    def test_post_request_on_custom_url_slug_view_contains_custom_url_in_location_header(self):
+        data = json.dumps({
+            'name': 'Foo',
+        })
+        url = reverse('backbone:tests_brand_alternate')
+        response = self.client.post(url, data, content_type='application/json')
+        self.assertEqual(response.status_code, 201)
+        self.assertEqual(Brand.objects.count(), 1)
+
+        self.assertEqual(
+            response['Location'],
+            'http://testserver' + reverse(
+                'backbone:tests_brand_alternate_detail', args=[Brand.objects.get().id]
+            )
+        )
+
 
 class UpdateTests(TestHelper):
 
