@@ -15,10 +15,14 @@ from backbone.serializers import AllFieldsSerializer
 class BackboneAPIView(View):
     model = None  # The model to be used for this API definition
     display_fields = []  # Fields to return for read (GET) requests,
+    display_collection_fields = [] # Specific fields to return for a read (GET) request of a model collection
+    display_detail_fields = [] # Specific fields to return for read (GET) requests for a specific model
     fields = []  # Fields to allow when adding (POST) or editing (PUT) objects.
     form = None  # The form class to be used for adding or editing objects.
     ordering = None  # Ordering used when retrieving the collection
     paginate_by = None  # The max number of objects per page (enables use of the ``page`` GET parameter).
+    url_slug = None  # The slug to be used when constructing the url (and url name) for this view.
+                     # Defaults to lowercase model name. Change this if you have multiple views for the same model.
 
     def queryset(self, request, **kwargs):
         """
@@ -43,7 +47,12 @@ class BackboneAPIView(View):
         """
         Handles get requests for the details of the given object.
         """
-        data = self.serialize(obj, ['id'] + list(self.display_fields))
+        if self.display_detail_fields:
+            display_fields = self.display_detail_fields
+        else:
+            display_fields = self.display_fields
+
+        data = self.serialize(obj, ['id'] + list(display_fields))
         return HttpResponse(self.json_dumps(data), content_type='application/json')
 
     def get_collection(self, request, **kwargs):
@@ -52,6 +61,11 @@ class BackboneAPIView(View):
         """
         qs = self.queryset(request, **kwargs)
 
+        if self.display_collection_fields:
+            display_fields = self.display_collection_fields
+        else:
+            display_fields = self.display_fields
+
         if self.paginate_by is not None:
             page = request.GET.get('page', 1)
             paginator = Paginator(qs, self.paginate_by)
@@ -64,7 +78,7 @@ class BackboneAPIView(View):
                 data = _('Invalid `page` parameter: Out of range.')
                 return HttpResponseBadRequest(data)
         data = [
-            self.serialize(obj, ['id'] + list(self.display_fields)) for obj in qs
+            self.serialize(obj, ['id'] + list(display_fields)) for obj in qs
         ]
         return HttpResponse(self.json_dumps(data), content_type='application/json')
 
@@ -103,7 +117,10 @@ class BackboneAPIView(View):
             response = self.get_object_detail(request, obj)
             response.status_code = 201
 
-            url_name = 'backbone:%s_%s_detail' % (self.model._meta.app_label, self.model._meta.module_name)
+            url_name = 'backbone:%s_%s_detail' % (
+                self.model._meta.app_label,
+                self.url_slug or self.model._meta.module_name
+            )
             response['Location'] = reverse(url_name, args=[obj.id])
             return response
         else:
